@@ -1,6 +1,4 @@
 import logging
-import sys
-import traceback
 
 from processrepo.Process import ProcessStatus
 from processrepo.repository.ProcessRepository import ProcessRepository
@@ -49,30 +47,3 @@ class ProcessBase:
 
     def report_process_status(self):
         self.process_reporter.report(self.process_name, self.market, self.process_run_profile, self.process_state)
-
-    def should_run_process(self) -> bool:
-        if self.intervene_process() is True:
-            return False
-        if self.process_state in [ProcessStatus.RUNNING, ProcessStatus.ERROR]:
-            return False
-        return True
-
-    def run(self):
-        if self.should_run_process():
-            try:
-                self.process_running()
-                self.process_to_run()
-                self.process_stopped()
-            except Exception as err:
-                exc_info = sys.exc_info()
-                self.log.warning(f'Process has an error:[{type(err)}] "{err}"')
-                self.process_error()
-                traceback.print_exception(*exc_info)
-
-    # override, by defining the process to run
-    def process_to_run(self):
-        pass
-
-    # any condition resulting in True, will prevent/intervene the process
-    def intervene_process(self) -> bool:
-        return False
